@@ -18,12 +18,6 @@ mod atomics_esp32c3;
 pub use error::*;
 pub use mutex::EspMutex;
 
-#[cfg(feature = "std")]
-pub use mutex::EspStdMutex;
-
-#[cfg(feature = "std")]
-pub use mutex::EspStdRwLock;
-
 #[cfg(feature = "std")]
 pub mod c_types {
     pub type c_void = std::os::raw::c_void;
